#
# PySNMP MIB module FRAME-RELAY-DTE-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/FRAME-RELAY-DTE-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:13:10 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, SingleValueConstraint, ValueRangeConstraint, ConstraintsUnion, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "SingleValueConstraint", "ValueRangeConstraint", "ConstraintsUnion", "ValueSizeConstraint")
( InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( Gauge32, Integer32, ModuleIdentity, MibIdentifier, iso, ObjectIdentity, TimeTicks, Bits, NotificationType, IpAddress, Counter64, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter32, Unsigned32, transmission, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Gauge32", "Integer32", "ModuleIdentity", "MibIdentifier", "iso", "ObjectIdentity", "TimeTicks", "Bits", "NotificationType", "IpAddress", "Counter64", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter32", "Unsigned32", "transmission")
( TextualConvention, DisplayString, RowStatus, TimeStamp, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "RowStatus", "TimeStamp")
frameRelayDTE = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 32)).setRevisions(("1997-05-01 02:29", "1992-04-01 00:00",))
if mibBuilder.loadTexts: frameRelayDTE.setLastUpdated('9705010229Z')
if mibBuilder.loadTexts: frameRelayDTE.setOrganization('IETF IPLPDN Working Group')
if mibBuilder.loadTexts: frameRelayDTE.setContactInfo('       Caralyn Brown\n            Postal: Cadia Networks, Inc.\n                    1 Corporate Drive\n                    Andover, Massachusetts  01810\n            Tel:    +1 508 689 2400 x133\n            E-Mail: cbrown@cadia.com\n\n                    Fred Baker\n            Postal: Cisco Systems\n                    519 Lado Drive\n                    Santa Barbara, California 93111\n            Tel:    +1 408 526 425\n            E-Mail: fred@cisco.com')
if mibBuilder.loadTexts: frameRelayDTE.setDescription('The MIB module to describe the use of a Frame Relay\n            interface by a DTE.')
class DLCI(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,8388607)

frDlcmiTable = MibTable((1, 3, 6, 1, 2, 1, 10, 32, 1), )
if mibBuilder.loadTexts: frDlcmiTable.setDescription('The Parameters for the Data Link Connection Management\n            Interface for the frame relay service on this\n            interface.')
frDlcmiEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 32, 1, 1), ).setIndexNames((0, "FRAME-RELAY-DTE-MIB", "frDlcmiIfIndex"))
if mibBuilder.loadTexts: frDlcmiEntry.setDescription('The Parameters for a particular Data Link Connection\n            Management Interface.')
frDlcmiIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 1, 1, 1), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frDlcmiIfIndex.setDescription('The ifIndex value of the corresponding ifEntry.')
frDlcmiState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("noLmiConfigured", 1), ("lmiRev1", 2), ("ansiT1617D", 3), ("ansiT1617B", 4), ("itut933A", 5), ("ansiT1617D1994", 6),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frDlcmiState.setDescription('This variable states which Data Link Connection\n            Management scheme is active (and by implication, what\n            DLCI it uses) on the Frame Relay interface.')
frDlcmiAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("q921", 1), ("q922March90", 2), ("q922November90", 3), ("q922", 4),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frDlcmiAddress.setDescription('This variable states which address format is in use on\n            the Frame Relay interface.')
frDlcmiAddressLen = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(2, 3, 4,))).clone(namedValues=NamedValues(("twoOctets", 2), ("threeOctets", 3), ("fourOctets", 4),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frDlcmiAddressLen.setDescription('This variable states the address length in octets.  In\n            the case of Q922 format, the length indicates the\n            entire length of the address including the control\n            portion.')
frDlcmiPollingInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 1, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(5,30)).clone(10)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: frDlcmiPollingInterval.setDescription('This is the number of seconds between successive\n            status enquiry messages.')
frDlcmiFullEnquiryInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 1, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,255)).clone(6)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frDlcmiFullEnquiryInterval.setDescription('Number of status enquiry intervals that pass before\n            issuance of a full status enquiry message.')
frDlcmiErrorThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 1, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10)).clone(3)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frDlcmiErrorThreshold.setDescription('This is the maximum number of unanswered Status\n            Enquiries the equipment shall accept before declaring\n            the interface down.')
frDlcmiMonitoredEvents = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 1, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10)).clone(4)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frDlcmiMonitoredEvents.setDescription("This is the number of status polling intervals over\n            which the error threshold is counted.  For example, if\n            within 'MonitoredEvents' number of events the station\n            receives 'ErrorThreshold' number of errors, the\n            interface is marked as down.")
frDlcmiMaxSupportedVCs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 1, 1, 9), DLCI()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frDlcmiMaxSupportedVCs.setDescription("The maximum number of Virtual Circuits allowed for\n            this interface.  Usually dictated by the Frame Relay\n            network.\n\n            In response to a SET, if a value less than zero or\n            higher than the agent's maximal capability is\n            configured, the agent should respond badValue")
frDlcmiMulticast = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 1, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("nonBroadcast", 1), ("broadcast", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frDlcmiMulticast.setDescription('This indicates whether the Frame Relay interface is\n            using a multicast service.')
frDlcmiStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 1, 1, 11), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("running", 1), ("fault", 2), ("initializing", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frDlcmiStatus.setDescription('This indicates the status of the Frame Relay interface\n            as determined by the performance of the dlcmi.  If no\n            dlcmi is running, the Frame Relay interface will stay\n            in the running state indefinitely.')
frDlcmiRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 1, 1, 12), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frDlcmiRowStatus.setDescription('SNMP Version 2 Row Status Variable.  Writable objects\n            in the table may be written in any RowStatus state.')
frCircuitTable = MibTable((1, 3, 6, 1, 2, 1, 10, 32, 2), )
if mibBuilder.loadTexts: frCircuitTable.setDescription('A table containing information about specific Data\n            Link Connections (DLC) or virtual circuits.')
frCircuitEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 32, 2, 1), ).setIndexNames((0, "FRAME-RELAY-DTE-MIB", "frCircuitIfIndex"), (0, "FRAME-RELAY-DTE-MIB", "frCircuitDlci"))
if mibBuilder.loadTexts: frCircuitEntry.setDescription('The information regarding a single Data Link\n            Connection.  Discontinuities in the counters contained\n            in this table are indicated by the value in\n            frCircuitCreationTime.')
frCircuitIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 1), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitIfIndex.setDescription('The ifIndex Value of the ifEntry this virtual circuit\n            is layered onto.')
frCircuitDlci = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 2), DLCI()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitDlci.setDescription('The Data Link Connection Identifier for this virtual\n            circuit.')
frCircuitState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("invalid", 1), ("active", 2), ("inactive", 3),)).clone('active')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frCircuitState.setDescription("Indicates whether the particular virtual circuit is\n            operational.  In the absence of a Data Link Connection\n            Management Interface, virtual circuit entries (rows)\n            may be created by setting virtual circuit state to\n            'active', or deleted by changing Circuit state to\n            'invalid'.\n\n            Whether or not the row actually disappears is left to\n            the implementation, so this object may actually read as\n            'invalid' for some arbitrary length of time.  It is\n            also legal to set the state of a virtual circuit to\n            'inactive' to temporarily disable a given circuit.\n\n            The use of 'invalid' is deprecated in this SNMP Version\n            2 MIB, in favor of frCircuitRowStatus.")
frCircuitReceivedFECNs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitReceivedFECNs.setDescription('Number of frames received from the network indicating\n            forward congestion since the virtual circuit was\n            created.  This occurs when the remote DTE sets the FECN\n            flag, or when a switch in the network enqueues the\n            frame to a trunk whose transmission queue is\n            congested.')
frCircuitReceivedBECNs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitReceivedBECNs.setDescription('Number of frames received from the network indicating\n            backward congestion since the virtual circuit was\n            created.  This occurs when the remote DTE sets the BECN\n            flag, or when a switch in the network receives the\n            frame from a trunk whose transmission queue is\n            congested.')
frCircuitSentFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitSentFrames.setDescription('The number of frames sent from this virtual circuit\n            since it was created.')
frCircuitSentOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitSentOctets.setDescription('The number of octets sent from this virtual circuit\n            since it was created.  Octets counted are the full\n            frame relay header and the payload, but do not include\n            the flag characters or CRC.')
frCircuitReceivedFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitReceivedFrames.setDescription('Number of frames received over this virtual circuit\n            since it was created.')
frCircuitReceivedOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitReceivedOctets.setDescription('Number of octets received over this virtual circuit\n            since it was created.  Octets counted include the full\n            frame relay header, but do not include the flag\n            characters or the CRC.')
frCircuitCreationTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 10), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitCreationTime.setDescription('The value of sysUpTime when the virtual circuit was\n            created, whether by the Data Link Connection Management\n            Interface or by a SetRequest.')
frCircuitLastTimeChange = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 11), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitLastTimeChange.setDescription('The value of sysUpTime when last there was a change in\n            the virtual circuit state')
frCircuitCommittedBurst = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 12), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frCircuitCommittedBurst.setDescription('This variable indicates the maximum amount of data, in\n            bits, that the network agrees to transfer under normal\n            conditions, during the measurement interval.')
frCircuitExcessBurst = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 13), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frCircuitExcessBurst.setDescription('This variable indicates the maximum amount of\n            uncommitted data bits that the network will attempt to\n            deliver over the measurement interval.\n\n            By default, if not configured when creating the entry,\n            the Excess Information Burst Size is set to the value\n            of ifSpeed.')
frCircuitThroughput = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 14), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frCircuitThroughput.setDescription("Throughput is the average number of 'Frame Relay\n            Information Field' bits transferred per second across a\n            user network interface in one direction, measured over\n            the measurement interval.\n\n            If the configured committed burst rate and throughput\n            are both non-zero, the measurement interval, T, is\n                T=frCircuitCommittedBurst/frCircuitThroughput.\n\n            If the configured committed burst rate and throughput\n            are both zero, the measurement interval, T, is\n                       T=frCircuitExcessBurst/ifSpeed.")
frCircuitMulticast = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 15), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("unicast", 1), ("oneWay", 2), ("twoWay", 3), ("nWay", 4),)).clone('unicast')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frCircuitMulticast.setDescription('This indicates whether this VC is used as a unicast VC\n            (i.e. not multicast) or the type of multicast service\n            subscribed to')
frCircuitType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 16), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("static", 1), ("dynamic", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitType.setDescription('Indication of whether the VC was manually created\n            (static), or dynamically created (dynamic) via the data\n            link control management interface.')
frCircuitDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitDiscards.setDescription('The number of inbound frames dropped because of format\n            errors, or because the VC is inactive.')
frCircuitReceivedDEs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitReceivedDEs.setDescription("Number of frames received from the network indicating\n            that they were eligible for discard since the virtual\n            circuit was created.  This occurs when the remote DTE\n            sets the DE flag, or when in remote DTE's switch\n            detects that the frame was received as Excess Burst\n            data.")
frCircuitSentDEs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frCircuitSentDEs.setDescription('Number of frames sent to the network indicating that\n            they were eligible for discard since the virtual\n            circuit was created.   This occurs when the local DTE\n            sets the DE flag, indicating that during Network\n            congestion situations those frames should be discarded\n            in preference of other frames sent without the DE bit\n            set.')
frCircuitLogicalIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 20), InterfaceIndex()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frCircuitLogicalIfIndex.setDescription('Normally the same value as frDlcmiIfIndex, but\n            different when an implementation associates a virtual\n            ifEntry with a DLC or set of DLCs in order to associate\n            higher layer objects such as the ipAddrEntry with a\n            subset of the virtual circuits on a Frame Relay\n            interface. The type of such ifEntries is defined by the\n            higher layer object; for example, if PPP/Frame Relay is\n            implemented, the ifType of this ifEntry would be PPP.\n            If it is not so defined, as would be the case with an\n            ipAddrEntry, it should be of type Other.')
frCircuitRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 2, 1, 21), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: frCircuitRowStatus.setDescription('This object is used to create a new row or modify or\n            destroy an existing row in the manner described in the\n            definition of the RowStatus textual convention.\n            Writable objects in the table may be written in any\n            RowStatus state.')
frErrTable = MibTable((1, 3, 6, 1, 2, 1, 10, 32, 3), )
if mibBuilder.loadTexts: frErrTable.setDescription('A table containing information about Errors on the\n            Frame Relay interface.  Discontinuities in the counters\n            contained in this table are the same as apply to the\n            ifEntry associated with the Interface.')
frErrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 32, 3, 1), ).setIndexNames((0, "FRAME-RELAY-DTE-MIB", "frErrIfIndex"))
if mibBuilder.loadTexts: frErrEntry.setDescription('The error information for a single frame relay\n            interface.')
frErrIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 3, 1, 1), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frErrIfIndex.setDescription('The ifIndex Value of the corresponding ifEntry.')
frErrType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 3, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10,))).clone(namedValues=NamedValues(("unknownError", 1), ("receiveShort", 2), ("receiveLong", 3), ("illegalAddress", 4), ("unknownAddress", 5), ("dlcmiProtoErr", 6), ("dlcmiUnknownIE", 7), ("dlcmiSequenceErr", 8), ("dlcmiUnknownRpt", 9), ("noErrorSinceReset", 10),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frErrType.setDescription('The type of error that was last seen  on  this interface:\n\n     receiveShort: frame was not long enough to allow\n             demultiplexing - the address field was incomplete,\n             or for virtual circuits using Multiprotocol over\n             Frame Relay, the protocol identifier was missing\n             or incomplete.\n\n     receiveLong: frame exceeded maximum length configured for this\n                  interface.\n\n     illegalAddress: address field did not match configured format.\n\n     unknownAddress: frame received on a virtual circuit which was not\n                     active or administratively disabled.\n\n     dlcmiProtoErr: unspecified error occurred when attempting to\n                    interpret link maintenance frame.\n\n     dlcmiUnknownIE: link maintenance frame contained an Information\n                     Element type which is not valid for the\n                     configured link maintenance protocol.\n\n     dlcmiSequenceErr: link maintenance frame contained a sequence\n                       number other than the expected value.\n\n     dlcmiUnknownRpt: link maintenance frame contained a Report Type\n                      Information Element whose value was not valid\n                      for the configured link maintenance protocol.\n\n     noErrorSinceReset: no errors have been detected since the last\n                        cold start or warm start.')
frErrData = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 3, 1, 3), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,1600))).setMaxAccess("readonly")
if mibBuilder.loadTexts: frErrData.setDescription('An octet string containing as much of the error packet\n            as possible.  As a minimum, it must contain the Q.922\n            Address or as much as was delivered.  It is desirable\n            to include all header and demultiplexing information.')
frErrTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 3, 1, 4), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frErrTime.setDescription('The value of sysUpTime at which the error was\n            detected.')
frErrFaults = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 3, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frErrFaults.setDescription('The number of times the interface has gone down since\n            it was initialized.')
frErrFaultTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 32, 3, 1, 6), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: frErrFaultTime.setDescription('The value of sysUpTime at the time when the interface\n            was taken down due to excessive errors.  Excessive\n            errors is defined as the time when a DLCMI exceeds the\n            frDlcmiErrorThreshold number of errors within\n            frDlcmiMonitoredEvents. See FrDlcmiEntry for further\n            details.')
frameRelayTrapControl = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 32, 4))
frameRelayTraps = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 32, 0))
frTrapState = MibScalar((1, 3, 6, 1, 2, 1, 10, 32, 4, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2),)).clone('disabled')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: frTrapState.setDescription('This variable indicates whether the system produces\n            the frDLCIStatusChange trap.')
frTrapMaxRate = MibScalar((1, 3, 6, 1, 2, 1, 10, 32, 4, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,3600000))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: frTrapMaxRate.setDescription('This variable indicates the number of milliseconds\n            that must elapse between trap emissions.  If events\n            occur more rapidly, the impementation may simply fail\n            to trap, or may queue traps until an appropriate time.')
frDLCIStatusChange = NotificationType((1, 3, 6, 1, 2, 1, 10, 32, 0, 1)).setObjects(*(("FRAME-RELAY-DTE-MIB", "frCircuitState"),))
if mibBuilder.loadTexts: frDLCIStatusChange.setDescription('This trap indicates that the indicated Virtual Circuit\n            has changed state.  It has either been created or\n            invalidated, or has toggled between the active and\n            inactive states.  If, however, the reason for the state\n            change is due to the DLCMI going down, per-DLCI traps\n            should not be generated.')
frConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 32, 6))
frGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 32, 6, 1))
frCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 32, 6, 2))
frCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 32, 6, 2, 1)).setObjects(*(("FRAME-RELAY-DTE-MIB", "frPortGroup"), ("FRAME-RELAY-DTE-MIB", "frCircuitGroup"), ("FRAME-RELAY-DTE-MIB", "frErrGroup"), ("FRAME-RELAY-DTE-MIB", "frTrapGroup"), ("FRAME-RELAY-DTE-MIB", "frNotificationGroup"),))
if mibBuilder.loadTexts: frCompliance.setDescription('The compliance statement ')
frCompliance0 = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 32, 6, 2, 2)).setObjects(*(("FRAME-RELAY-DTE-MIB", "frPortGroup0"), ("FRAME-RELAY-DTE-MIB", "frCircuitGroup0"), ("FRAME-RELAY-DTE-MIB", "frErrGroup0"), ("FRAME-RELAY-DTE-MIB", "frTrapGroup0"), ("FRAME-RELAY-DTE-MIB", "frNotificationGroup"),))
if mibBuilder.loadTexts: frCompliance0.setDescription('The compliance statement for objects and the trap\n            defined in RFC 1315.')
frPortGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 32, 6, 1, 1)).setObjects(*(("FRAME-RELAY-DTE-MIB", "frDlcmiIfIndex"), ("FRAME-RELAY-DTE-MIB", "frDlcmiState"), ("FRAME-RELAY-DTE-MIB", "frDlcmiAddress"), ("FRAME-RELAY-DTE-MIB", "frDlcmiAddressLen"), ("FRAME-RELAY-DTE-MIB", "frDlcmiPollingInterval"), ("FRAME-RELAY-DTE-MIB", "frDlcmiFullEnquiryInterval"), ("FRAME-RELAY-DTE-MIB", "frDlcmiErrorThreshold"), ("FRAME-RELAY-DTE-MIB", "frDlcmiMonitoredEvents"), ("FRAME-RELAY-DTE-MIB", "frDlcmiMaxSupportedVCs"), ("FRAME-RELAY-DTE-MIB", "frDlcmiMulticast"), ("FRAME-RELAY-DTE-MIB", "frDlcmiStatus"), ("FRAME-RELAY-DTE-MIB", "frDlcmiRowStatus"),))
if mibBuilder.loadTexts: frPortGroup.setDescription('The objects necessary to control the Link Management\n            Interface for a Frame Relay Interface as well as\n            maintain the error statistics on this interface.')
frCircuitGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 32, 6, 1, 2)).setObjects(*(("FRAME-RELAY-DTE-MIB", "frCircuitIfIndex"), ("FRAME-RELAY-DTE-MIB", "frCircuitDlci"), ("FRAME-RELAY-DTE-MIB", "frCircuitState"), ("FRAME-RELAY-DTE-MIB", "frCircuitReceivedFECNs"), ("FRAME-RELAY-DTE-MIB", "frCircuitReceivedBECNs"), ("FRAME-RELAY-DTE-MIB", "frCircuitSentFrames"), ("FRAME-RELAY-DTE-MIB", "frCircuitSentOctets"), ("FRAME-RELAY-DTE-MIB", "frCircuitReceivedFrames"), ("FRAME-RELAY-DTE-MIB", "frCircuitReceivedOctets"), ("FRAME-RELAY-DTE-MIB", "frCircuitCreationTime"), ("FRAME-RELAY-DTE-MIB", "frCircuitLastTimeChange"), ("FRAME-RELAY-DTE-MIB", "frCircuitCommittedBurst"), ("FRAME-RELAY-DTE-MIB", "frCircuitExcessBurst"), ("FRAME-RELAY-DTE-MIB", "frCircuitThroughput"), ("FRAME-RELAY-DTE-MIB", "frCircuitMulticast"), ("FRAME-RELAY-DTE-MIB", "frCircuitType"), ("FRAME-RELAY-DTE-MIB", "frCircuitDiscards"), ("FRAME-RELAY-DTE-MIB", "frCircuitReceivedDEs"), ("FRAME-RELAY-DTE-MIB", "frCircuitSentDEs"), ("FRAME-RELAY-DTE-MIB", "frCircuitLogicalIfIndex"), ("FRAME-RELAY-DTE-MIB", "frCircuitRowStatus"),))
if mibBuilder.loadTexts: frCircuitGroup.setDescription('The objects necessary to control the Virtual Circuits\n            layered onto a Frame Relay Interface.')
frTrapGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 32, 6, 1, 3)).setObjects(*(("FRAME-RELAY-DTE-MIB", "frTrapState"), ("FRAME-RELAY-DTE-MIB", "frTrapMaxRate"),))
if mibBuilder.loadTexts: frTrapGroup.setDescription("The objects necessary to control a Frame Relay\n            Interface's notification messages.")
frErrGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 32, 6, 1, 4)).setObjects(*(("FRAME-RELAY-DTE-MIB", "frErrIfIndex"), ("FRAME-RELAY-DTE-MIB", "frErrType"), ("FRAME-RELAY-DTE-MIB", "frErrData"), ("FRAME-RELAY-DTE-MIB", "frErrTime"), ("FRAME-RELAY-DTE-MIB", "frErrFaults"), ("FRAME-RELAY-DTE-MIB", "frErrFaultTime"),))
if mibBuilder.loadTexts: frErrGroup.setDescription('Objects designed to assist in debugging Frame Relay\n            Interfaces.')
frNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 32, 6, 1, 5)).setObjects(*(("FRAME-RELAY-DTE-MIB", "frDLCIStatusChange"),))
if mibBuilder.loadTexts: frNotificationGroup.setDescription('Traps which may be used to enhance event driven\n            management of the interface.')
frPortGroup0 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 32, 6, 1, 6)).setObjects(*(("FRAME-RELAY-DTE-MIB", "frDlcmiIfIndex"), ("FRAME-RELAY-DTE-MIB", "frDlcmiState"), ("FRAME-RELAY-DTE-MIB", "frDlcmiAddress"), ("FRAME-RELAY-DTE-MIB", "frDlcmiAddressLen"), ("FRAME-RELAY-DTE-MIB", "frDlcmiPollingInterval"), ("FRAME-RELAY-DTE-MIB", "frDlcmiFullEnquiryInterval"), ("FRAME-RELAY-DTE-MIB", "frDlcmiErrorThreshold"), ("FRAME-RELAY-DTE-MIB", "frDlcmiMonitoredEvents"), ("FRAME-RELAY-DTE-MIB", "frDlcmiMaxSupportedVCs"), ("FRAME-RELAY-DTE-MIB", "frDlcmiMulticast"),))
if mibBuilder.loadTexts: frPortGroup0.setDescription('The objects necessary to control the Link Management\n            Interface for a Frame Relay Interface as well as\n            maintain the error statistics on this interface from\n            RFC 1315.')
frCircuitGroup0 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 32, 6, 1, 7)).setObjects(*(("FRAME-RELAY-DTE-MIB", "frCircuitIfIndex"), ("FRAME-RELAY-DTE-MIB", "frCircuitDlci"), ("FRAME-RELAY-DTE-MIB", "frCircuitState"), ("FRAME-RELAY-DTE-MIB", "frCircuitReceivedFECNs"), ("FRAME-RELAY-DTE-MIB", "frCircuitReceivedBECNs"), ("FRAME-RELAY-DTE-MIB", "frCircuitSentFrames"), ("FRAME-RELAY-DTE-MIB", "frCircuitSentOctets"), ("FRAME-RELAY-DTE-MIB", "frCircuitReceivedFrames"), ("FRAME-RELAY-DTE-MIB", "frCircuitReceivedOctets"), ("FRAME-RELAY-DTE-MIB", "frCircuitCreationTime"), ("FRAME-RELAY-DTE-MIB", "frCircuitLastTimeChange"), ("FRAME-RELAY-DTE-MIB", "frCircuitCommittedBurst"), ("FRAME-RELAY-DTE-MIB", "frCircuitExcessBurst"), ("FRAME-RELAY-DTE-MIB", "frCircuitThroughput"),))
if mibBuilder.loadTexts: frCircuitGroup0.setDescription('The objects necessary to control the Virtual Circuits\n            layered onto a Frame Relay Interface from RFC 1315.')
frErrGroup0 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 32, 6, 1, 8)).setObjects(*(("FRAME-RELAY-DTE-MIB", "frErrIfIndex"), ("FRAME-RELAY-DTE-MIB", "frErrType"), ("FRAME-RELAY-DTE-MIB", "frErrData"), ("FRAME-RELAY-DTE-MIB", "frErrTime"),))
if mibBuilder.loadTexts: frErrGroup0.setDescription('Objects designed to assist in debugging Frame Relay\n            Interfaces from RFC 1315.')
frTrapGroup0 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 32, 6, 1, 9)).setObjects(*(("FRAME-RELAY-DTE-MIB", "frTrapState"),))
if mibBuilder.loadTexts: frTrapGroup0.setDescription("The objects necessary to control a Frame Relay\n            Interface's notification messages from RFC 1315.")
mibBuilder.exportSymbols("FRAME-RELAY-DTE-MIB", frErrTable=frErrTable, frDlcmiPollingInterval=frDlcmiPollingInterval, frameRelayDTE=frameRelayDTE, frCompliance0=frCompliance0, frErrType=frErrType, frDlcmiIfIndex=frDlcmiIfIndex, frCircuitReceivedFrames=frCircuitReceivedFrames, frDlcmiTable=frDlcmiTable, frTrapGroup=frTrapGroup, frErrEntry=frErrEntry, frCircuitReceivedFECNs=frCircuitReceivedFECNs, frErrGroup0=frErrGroup0, frCircuitSentFrames=frCircuitSentFrames, frErrFaultTime=frErrFaultTime, frCircuitReceivedOctets=frCircuitReceivedOctets, frDlcmiFullEnquiryInterval=frDlcmiFullEnquiryInterval, frDlcmiEntry=frDlcmiEntry, frDlcmiErrorThreshold=frDlcmiErrorThreshold, frCircuitDiscards=frCircuitDiscards, frGroups=frGroups, frTrapMaxRate=frTrapMaxRate, frCircuitGroup0=frCircuitGroup0, frCircuitType=frCircuitType, frameRelayTrapControl=frameRelayTrapControl, frCircuitMulticast=frCircuitMulticast, frDlcmiMulticast=frDlcmiMulticast, frCircuitSentOctets=frCircuitSentOctets, frCircuitIfIndex=frCircuitIfIndex, frCircuitState=frCircuitState, frCircuitEntry=frCircuitEntry, frDlcmiAddressLen=frDlcmiAddressLen, frPortGroup=frPortGroup, frErrFaults=frErrFaults, frCircuitExcessBurst=frCircuitExcessBurst, frDlcmiStatus=frDlcmiStatus, frNotificationGroup=frNotificationGroup, frPortGroup0=frPortGroup0, frCircuitGroup=frCircuitGroup, frErrGroup=frErrGroup, frCircuitCommittedBurst=frCircuitCommittedBurst, frCircuitLogicalIfIndex=frCircuitLogicalIfIndex, frCircuitReceivedDEs=frCircuitReceivedDEs, frCircuitSentDEs=frCircuitSentDEs, frTrapState=frTrapState, frCircuitTable=frCircuitTable, frDlcmiAddress=frDlcmiAddress, frCircuitCreationTime=frCircuitCreationTime, PYSNMP_MODULE_ID=frameRelayDTE, frDlcmiMonitoredEvents=frDlcmiMonitoredEvents, frDlcmiRowStatus=frDlcmiRowStatus, frErrData=frErrData, DLCI=DLCI, frErrIfIndex=frErrIfIndex, frDLCIStatusChange=frDLCIStatusChange, frCompliances=frCompliances, frCompliance=frCompliance, frCircuitThroughput=frCircuitThroughput, frTrapGroup0=frTrapGroup0, frErrTime=frErrTime, frCircuitLastTimeChange=frCircuitLastTimeChange, frCircuitDlci=frCircuitDlci, frConformance=frConformance, frDlcmiMaxSupportedVCs=frDlcmiMaxSupportedVCs, frDlcmiState=frDlcmiState, frameRelayTraps=frameRelayTraps, frCircuitRowStatus=frCircuitRowStatus, frCircuitReceivedBECNs=frCircuitReceivedBECNs)



#
# PySNMP MIB module GMPLS-LSR-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/GMPLS-LSR-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:14:00 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ValueSizeConstraint, SingleValueConstraint, ConstraintsUnion, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueRangeConstraint")
( GmplsSegmentDirectionTC, ) = mibBuilder.importSymbols("GMPLS-TC-STD-MIB", "GmplsSegmentDirectionTC")
( ifCounterDiscontinuityGroup, ifGeneralInformationGroup, ) = mibBuilder.importSymbols("IF-MIB", "ifCounterDiscontinuityGroup", "ifGeneralInformationGroup")
( mplsInterfaceIndex, mplsOutSegmentIndex, mplsLsrNotificationGroup, mplsPerfGroup, mplsXCGroup, mplsInSegmentGroup, mplsInSegmentIndex, mplsInterfaceGroup, mplsOutSegmentGroup, ) = mibBuilder.importSymbols("MPLS-LSR-STD-MIB", "mplsInterfaceIndex", "mplsOutSegmentIndex", "mplsLsrNotificationGroup", "mplsPerfGroup", "mplsXCGroup", "mplsInSegmentGroup", "mplsInSegmentIndex", "mplsInterfaceGroup", "mplsOutSegmentGroup")
( mplsStdMIB, ) = mibBuilder.importSymbols("MPLS-TC-STD-MIB", "mplsStdMIB")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( IpAddress, Unsigned32, Counter32, iso, TimeTicks, Counter64, Bits, ModuleIdentity, zeroDotZero, Gauge32, NotificationType, ObjectIdentity, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "Unsigned32", "Counter32", "iso", "TimeTicks", "Counter64", "Bits", "ModuleIdentity", "zeroDotZero", "Gauge32", "NotificationType", "ObjectIdentity", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Integer32")
( TextualConvention, DisplayString, RowPointer, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "RowPointer")
gmplsLsrStdMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 166, 15)).setRevisions(("2007-02-27 00:00",))
if mibBuilder.loadTexts: gmplsLsrStdMIB.setLastUpdated('200702270000Z')
if mibBuilder.loadTexts: gmplsLsrStdMIB.setOrganization('IETF Common Control And Measurement Plane (CCAMP) Working Group')
if mibBuilder.loadTexts: gmplsLsrStdMIB.setContactInfo('       Thomas D. Nadeau\n            Cisco Systems, Inc.\n     Email: tnadeau@cisco.com\n            Adrian Farrel\n            Old Dog Consulting\n\n     Email: adrian@olddog.co.uk\n     Comments about this document should be emailed directly to the\n     CCAMP working group mailing list at ccamp@ops.ietf.org.')
if mibBuilder.loadTexts: gmplsLsrStdMIB.setDescription('Copyright (C) The IETF Trust (2007).  This version of\n     this MIB module is part of RFC 4803; see the RFC itself for\n     full legal notices.\n\n     This MIB module contains managed object definitions for the\n     Generalized Multiprotocol (GMPLS) Label Switching Router as\n     defined in Generalized Multi-Protocol Label Switching (GMPLS)\n     Architecture, Mannie et al., RFC 3945, October 2004.')
gmplsLsrObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 15, 1))
gmplsLsrConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 15, 2))
gmplsInterfaceTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 1), )
if mibBuilder.loadTexts: gmplsInterfaceTable.setDescription('This table specifies per-interface GMPLS capability and\n     associated information.  It extends the information in the\n     mplsInterfaceTable of MPLS-LSR-STD-MIB through a\n     sparse augmentation relationship.')
gmplsInterfaceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 1, 1), ).setIndexNames((0, "MPLS-LSR-STD-MIB", "mplsInterfaceIndex"))
if mibBuilder.loadTexts: gmplsInterfaceEntry.setDescription('A conceptual row in this table is created automatically by an\n     LSR for each interface that is both capable of supporting\n     GMPLS and configured to support GMPLS.  Note that\n     support of GMPLS is not limited to control plane signaling,\n     but may include data-plane-only function configured through\n     SNMP SET commands performed on this MIB module.\n     A conceptual row in this table may also be created via SNMP\n     SET commands or automatically by the LSR to supplement a\n     conceptual row in the mplsInterfaceTable where the interface\n     is not capable of GMPLS but where the other objects carried\n     in this row provide useful additional information for an\n     MPLS interface.\n\n     A conceptual row in this table will exist if and only if a\n     corresponding entry in the mplsInterfaceTable exists, and a\n     corresponding entry in the ifTable exists with ifType = mpls(166).\n     If the associated entry in the ifTable is operationally disabled\n     (thus removing the GMPLS capabilities on the interface) or the\n     entry in the mplsInterfaceTable is deleted, the corresponding entry\n     in this table MUST be deleted shortly thereafter.\n\n     The indexes are the same as for the mplsInterfaceTable.  Thus, the\n     entry with index 0 represents the per-platform label space and\n     contains parameters that apply to all interfaces that\n     participate in the per-platform label space.')
gmplsInterfaceSignalingCaps = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 1, 1, 1), Bits().clone(namedValues=NamedValues(("unknown", 0), ("rsvpGmpls", 1), ("crldpGmpls", 2), ("otherGmpls", 3),)).clone(namedValues=NamedValues(("rsvpGmpls", 1),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsInterfaceSignalingCaps.setDescription("Defines the signaling capabilities on this interface.  Multiple\n     bits may legitimately be set at once, but if 'unknown' is set\n     then no other bit may be set.  Setting no bits implies that GMPLS\n     signaling cannot be performed on this interface and all LSPs\n     must be manually provisioned or that this table entry is only\n     present to supplement an entry in the mplsInterfaceTable by\n     providing the information carried in other objects in this row.")
gmplsInterfaceRsvpHelloPeriod = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 1, 1, 2), Unsigned32().clone(3000)).setUnits('milliseconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsInterfaceRsvpHelloPeriod.setDescription('Period, in milliseconds, between sending Resource Reservation\n     Protocol (RSVP) Hello messages on this interface.  A value of 0\n     indicates that no Hello messages should be sent on this\n     interface.\n\n     This object is only valid if gmplsInterfaceSignalingCaps has no\n     bits set or includes the rsvpGmpls bit.')
gmplsInSegmentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 2), )
if mibBuilder.loadTexts: gmplsInSegmentTable.setDescription('This table sparse augments the mplsInSegmentTable of\n     MPLS-LSR-STD-MIB to provide GMPLS-specific information about\n     incoming segments to an LSR.')
gmplsInSegmentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 2, 1), ).setIndexNames((0, "MPLS-LSR-STD-MIB", "mplsInSegmentIndex"))
if mibBuilder.loadTexts: gmplsInSegmentEntry.setDescription('An entry in this table extends the representation of an incoming\n     segment represented by an entry in the mplsInSegmentTable in\n     MPLS-LSR-STD-MIB through a sparse augmentation.  An entry can be\n     created by a network administrator via SNMP SET commands, or in\n     response to signaling protocol events.\n\n     Note that the storage type for this entry is given by the value\n     of mplsInSegmentStorageType in the corresponding entry of the\n     mplsInSegmentTable.')
gmplsInSegmentDirection = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 2, 1, 1), GmplsSegmentDirectionTC().clone('forward')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsInSegmentDirection.setDescription('This object indicates the direction of data flow on this\n     segment.  This object cannot be modified if\n     mplsInSegmentRowStatus for the corresponding entry in the\n     mplsInSegmentTable is active(1).')
gmplsInSegmentExtraParamsPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 2, 1, 2), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsInSegmentExtraParamsPtr.setDescription('Some tunnels will run over transports that can usefully support\n     technology-specific additional parameters (for example,\n     Synchronous Optical Network (SONET) resource usage).  Such can be\n     supplied from an external table and referenced from here.  A value\n     of zeroDotZero in this attribute indicates that there is no such\n     additional information.')
gmplsOutSegmentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 3), )
if mibBuilder.loadTexts: gmplsOutSegmentTable.setDescription('This table sparse augments the mplsOutSegmentTable of\n     MPLS-LSR-STD-MIB to provide GMPLS-specific information about\n     outgoing segments from an LSR.')
gmplsOutSegmentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 3, 1), ).setIndexNames((0, "MPLS-LSR-STD-MIB", "mplsOutSegmentIndex"))
if mibBuilder.loadTexts: gmplsOutSegmentEntry.setDescription('An entry in this table extends the representation of an outgoing\n     segment represented by an entry in the mplsOutSegmentTable of\n     MPLS-LSR-STD-MIB through a sparse augmentation.  An entry can be\n     created by a network administrator via SNMP SET commands, or in\n     response to signaling protocol events.\n\n     Note that the storage type for this entry is given by the value\n     of mplsOutSegmentStorageType in the corresponding entry of the\n     mplsOutSegmentTable.')
gmplsOutSegmentDirection = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 3, 1, 1), GmplsSegmentDirectionTC().clone('forward')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsOutSegmentDirection.setDescription('This object indicates the direction of data flow on this\n     segment.  This object cannot be modified if\n     mplsOutSegmentRowStatus for the corresponding entry in the\n     mplsOutSegmentTable is active(1).')
gmplsOutSegmentTTLDecrement = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 3, 1, 2), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsOutSegmentTTLDecrement.setDescription('This object indicates the amount by which to decrement the Time\n     to Live (TTL) of any payload packets forwarded on this segment if\n     per-hop decrementing is being done.\n\n     A value of zero indicates that no decrement should be made or\n     that per-hop decrementing is not in use.\n\n     See the gmplsTunnelTTLDecrement object in the gmplsTunnelTable\n     of GMPLS-TE-STD-MIB for a value by which to decrement the TTL\n     for the whole of a tunnel.\n\n     This object cannot be modified if mplsOutSegmentRowStatus for\n     the associated entry in the mplsOutSegmentTable is active(1).')
gmplsOutSegmentExtraParamsPtr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 15, 1, 3, 1, 3), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: gmplsOutSegmentExtraParamsPtr.setDescription('Some tunnels will run over transports that can usefully support\n     technology-specific additional parameters (for example, SONET\n     resource usage).  Such can be supplied from an external table and\n     referenced from here.\n\n     A value of zeroDotZero in this attribute indicates that there is\n     no such additional information.')
gmplsLsrGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 15, 2, 1))
gmplsLsrCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 15, 2, 2))
gmplsLsrModuleFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 15, 2, 2, 1)).setObjects(*(("IF-MIB", "ifGeneralInformationGroup"), ("IF-MIB", "ifCounterDiscontinuityGroup"), ("MPLS-LSR-STD-MIB", "mplsInterfaceGroup"), ("MPLS-LSR-STD-MIB", "mplsInSegmentGroup"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentGroup"), ("MPLS-LSR-STD-MIB", "mplsXCGroup"), ("MPLS-LSR-STD-MIB", "mplsPerfGroup"), ("MPLS-LSR-STD-MIB", "mplsLsrNotificationGroup"), ("GMPLS-LSR-STD-MIB", "gmplsInterfaceGroup"), ("GMPLS-LSR-STD-MIB", "gmplsInSegmentGroup"), ("GMPLS-LSR-STD-MIB", "gmplsOutSegmentGroup"),))
if mibBuilder.loadTexts: gmplsLsrModuleFullCompliance.setDescription('Compliance statement for agents that provide full support for\n     GMPLS-LSR-STD-MIB.\n\n     The mandatory group has to be implemented by all LSRs that\n     originate, terminate, or act as transit for TE-LSPs/tunnels.\n     In addition, depending on the type of tunnels supported, other\n     groups become mandatory as explained below.')
gmplsLsrModuleReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 15, 2, 2, 2)).setObjects(*(("IF-MIB", "ifGeneralInformationGroup"), ("IF-MIB", "ifCounterDiscontinuityGroup"), ("MPLS-LSR-STD-MIB", "mplsInterfaceGroup"), ("MPLS-LSR-STD-MIB", "mplsInSegmentGroup"), ("MPLS-LSR-STD-MIB", "mplsOutSegmentGroup"), ("MPLS-LSR-STD-MIB", "mplsXCGroup"), ("MPLS-LSR-STD-MIB", "mplsPerfGroup"), ("GMPLS-LSR-STD-MIB", "gmplsInterfaceGroup"), ("GMPLS-LSR-STD-MIB", "gmplsInSegmentGroup"), ("GMPLS-LSR-STD-MIB", "gmplsOutSegmentGroup"),))
if mibBuilder.loadTexts: gmplsLsrModuleReadOnlyCompliance.setDescription('Compliance requirement for implementations that only provide\n     read-only support for GMPLS-LSR-STD-MIB.  Such devices can then\n     be monitored but cannot be configured using this MIB module.')
gmplsInterfaceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 15, 2, 1, 1)).setObjects(*(("GMPLS-LSR-STD-MIB", "gmplsInterfaceSignalingCaps"), ("GMPLS-LSR-STD-MIB", "gmplsInterfaceRsvpHelloPeriod"),))
if mibBuilder.loadTexts: gmplsInterfaceGroup.setDescription('Collection of objects that provide additional\n    information for an MPLS interface and are needed\n    for GMPLS interface configuration and performance\n    information.')
gmplsInSegmentGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 15, 2, 1, 2)).setObjects(*(("GMPLS-LSR-STD-MIB", "gmplsInSegmentDirection"), ("GMPLS-LSR-STD-MIB", "gmplsInSegmentExtraParamsPtr"),))
if mibBuilder.loadTexts: gmplsInSegmentGroup.setDescription('Collection of objects that provide additional\n     information for an MPLS in-segment and are needed\n     for GMPLS in-segment configuration and performance\n     information.')
gmplsOutSegmentGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 15, 2, 1, 3)).setObjects(*(("GMPLS-LSR-STD-MIB", "gmplsOutSegmentDirection"), ("GMPLS-LSR-STD-MIB", "gmplsOutSegmentTTLDecrement"), ("GMPLS-LSR-STD-MIB", "gmplsOutSegmentExtraParamsPtr"),))
if mibBuilder.loadTexts: gmplsOutSegmentGroup.setDescription('Collection of objects that provide additional\n     information for an MPLS out-segment and are needed\n     for GMPLS out-segment configuration and performance\n     information.')
mibBuilder.exportSymbols("GMPLS-LSR-STD-MIB", gmplsInterfaceTable=gmplsInterfaceTable, gmplsLsrConformance=gmplsLsrConformance, gmplsOutSegmentTTLDecrement=gmplsOutSegmentTTLDecrement, gmplsLsrModuleReadOnlyCompliance=gmplsLsrModuleReadOnlyCompliance, gmplsOutSegmentTable=gmplsOutSegmentTable, gmplsInSegmentGroup=gmplsInSegmentGroup, gmplsOutSegmentDirection=gmplsOutSegmentDirection, gmplsInterfaceGroup=gmplsInterfaceGroup, gmplsLsrGroups=gmplsLsrGroups, gmplsInSegmentEntry=gmplsInSegmentEntry, gmplsLsrModuleFullCompliance=gmplsLsrModuleFullCompliance, gmplsInterfaceEntry=gmplsInterfaceEntry, PYSNMP_MODULE_ID=gmplsLsrStdMIB, gmplsLsrCompliances=gmplsLsrCompliances, gmplsOutSegmentEntry=gmplsOutSegmentEntry, gmplsInSegmentTable=gmplsInSegmentTable, gmplsOutSegmentExtraParamsPtr=gmplsOutSegmentExtraParamsPtr, gmplsLsrStdMIB=gmplsLsrStdMIB, gmplsInSegmentExtraParamsPtr=gmplsInSegmentExtraParamsPtr, gmplsLsrObjects=gmplsLsrObjects, gmplsOutSegmentGroup=gmplsOutSegmentGroup, gmplsInterfaceRsvpHelloPeriod=gmplsInterfaceRsvpHelloPeriod, gmplsInSegmentDirection=gmplsInSegmentDirection, gmplsInterfaceSignalingCaps=gmplsInterfaceSignalingCaps)



#
# PySNMP MIB module SONET-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/SONET-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:12:12 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsUnion, ValueSizeConstraint, ConstraintsIntersection, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsUnion", "ValueSizeConstraint", "ConstraintsIntersection", "ValueRangeConstraint")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( PerfCurrentCount, PerfIntervalCount, ) = mibBuilder.importSymbols("PerfHist-TC-MIB", "PerfCurrentCount", "PerfIntervalCount")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( Integer32, ModuleIdentity, Gauge32, Unsigned32, Bits, NotificationType, iso, transmission, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter64, MibIdentifier, IpAddress, Counter32, ObjectIdentity, TimeTicks, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "ModuleIdentity", "Gauge32", "Unsigned32", "Bits", "NotificationType", "iso", "transmission", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter64", "MibIdentifier", "IpAddress", "Counter32", "ObjectIdentity", "TimeTicks")
( TruthValue, TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TruthValue", "TextualConvention", "DisplayString")
sonetMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 39)).setRevisions(("2003-08-11 00:00", "1998-10-19 00:00", "1994-01-03 00:00",))
if mibBuilder.loadTexts: sonetMIB.setLastUpdated('200308110000Z')
if mibBuilder.loadTexts: sonetMIB.setOrganization('IETF AToM MIB Working Group')
if mibBuilder.loadTexts: sonetMIB.setContactInfo('WG charter:\n            http://www.ietf.org/html.charters/atommib-charter.html\n\n          Mailing Lists:\n            General Discussion: atommib@research.telcordia.com\n            To Subscribe: atommib-request@research.telcordia.com\n\n          Kaj Tesink\n          Telcordia Technologies\n          Tel: (732) 758-5254\n          Fax: (732) 758-2269\n          E-mail: kaj@research.telcordia.com.')
if mibBuilder.loadTexts: sonetMIB.setDescription('The MIB module to describe SONET/SDH interface objects.\n\n          Copyright (C) The Internet Society (2003).  This version\n          of this MIB module is part of RFC 3592;  see the RFC\n          itself for full legal notices.')
sonetObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 1))
sonetObjectsPath = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 2))
sonetObjectsVT = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 3))
sonetMedium = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 1, 1))
sonetSection = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 1, 2))
sonetLine = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 1, 3))
sonetFarEndLine = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 1, 4))
sonetPath = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 2, 1))
sonetFarEndPath = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 2, 2))
sonetVT = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 3, 1))
sonetFarEndVT = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 3, 2))
sonetMediumTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 1, 1, 1), )
if mibBuilder.loadTexts: sonetMediumTable.setDescription('The SONET/SDH Medium table.')
sonetMediumEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 1, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: sonetMediumEntry.setDescription('An entry in the SONET/SDH Medium table.')
sonetMediumType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("sonet", 1), ("sdh", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sonetMediumType.setDescription('This variable identifies whether a SONET\n          or a SDH signal is used across this interface.')
sonetMediumTimeElapsed = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 1, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,900))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetMediumTimeElapsed.setDescription("The number of seconds, including partial seconds,\n          that have elapsed since the beginning of the current\n          measurement period. If, for some reason, such as an\n          adjustment in the system's time-of-day clock, the\n          current interval exceeds the maximum value, the\n          agent will return the maximum value.")
sonetMediumValidIntervals = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,96))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetMediumValidIntervals.setDescription('The number of previous 15-minute intervals\n          for which data was collected.\n          A SONET/SDH interface must be capable\n          of supporting at least n intervals.\n          The minimum value of n is 4.\n          The default of n is 32.\n          The maximum value of n is 96.\n          The value will be <n> unless the measurement was\n          (re-)started within the last (<n>*15) minutes, in which\n          case the value will be the number of complete 15\n          minute intervals for which the agent has at least\n          some data. In certain cases (e.g., in the case\n          where the agent is a proxy) it is possible that some\n          intervals are unavailable.  In this case, this\n          interval is the maximum interval number for\n          which data is available. ')
sonetMediumLineCoding = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("sonetMediumOther", 1), ("sonetMediumB3ZS", 2), ("sonetMediumCMI", 3), ("sonetMediumNRZ", 4), ("sonetMediumRZ", 5),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sonetMediumLineCoding.setDescription('This variable describes the line coding for\n          this interface. The B3ZS and CMI are used for\n          electrical SONET/SDH signals (STS-1 and STS-3).\n          The Non-Return to Zero (NRZ) and the Return\n          to Zero are used for optical SONET/SDH signals.')
sonetMediumLineType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 1, 1, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("sonetOther", 1), ("sonetShortSingleMode", 2), ("sonetLongSingleMode", 3), ("sonetMultiMode", 4), ("sonetCoax", 5), ("sonetUTP", 6),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sonetMediumLineType.setDescription('This variable describes the line type for\n          this interface. The line types are\n          Short and Long Range\n          Single Mode fiber or Multi-Mode fiber interfaces,\n          and coax and UTP for electrical interfaces.  The\n          value sonetOther should be used when the Line Type is\n          not one of the listed values.')
sonetMediumCircuitIdentifier = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 1, 1, 1, 6), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sonetMediumCircuitIdentifier.setDescription("This variable contains the transmission\n          vendor's circuit identifier, for the\n          purpose of facilitating troubleshooting.\n          Note that the circuit identifier, if available,\n          is also represented by ifPhysAddress.")
sonetMediumInvalidIntervals = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 1, 1, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,96))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetMediumInvalidIntervals.setDescription('The number of intervals in the range from\n           0 to sonetMediumValidIntervals for which no\n           data is available. This object will typically\n           be zero except in cases where the data for some\n           intervals are not available (e.g., in proxy\n           situations).')
sonetMediumLoopbackConfig = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 1, 1, 1, 8), Bits().clone(namedValues=NamedValues(("sonetNoLoop", 0), ("sonetFacilityLoop", 1), ("sonetTerminalLoop", 2), ("sonetOtherLoop", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sonetMediumLoopbackConfig.setDescription('The current loopback state of the SONET/SDH interface.  The\n           values mean:\n\n             sonetNoLoop\n                Not in the loopback state. A device that is not\n                capable of performing a loopback on this interface\n                shall always return this value.\n\n             sonetFacilityLoop\n                The received signal at this interface is looped back\n                out through the corresponding transmitter in the return\n                direction.\n\n             sonetTerminalLoop\n                The signal that is about to be transmitted is connected\n                to the associated incoming receiver.\n\n             sonetOtherLoop\n                Loopbacks that are not defined here.')
sonetSESthresholdSet = MibScalar((1, 3, 6, 1, 2, 1, 10, 39, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("bellcore1991", 2), ("ansi1993", 3), ("itu1995", 4), ("ansi1997", 5),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sonetSESthresholdSet.setDescription('An enumerated integer indicating which\n          recognized set of SES thresholds that\n          the agent uses for determining severely\n          errored seconds and unavailable time.\n\n          other(1)\n            None of the following.\n\n          bellcore1991(2)\n            Bellcore TR-NWT-000253, 1991 [TR253], or\n            ANSI T1M1.3/93-005R2, 1993 [T1M1.3].\n            See also Appendix B.\n\n          ansi1993(3)\n            ANSI T1.231, 1993 [T1.231a], or\n            Bellcore GR-253-CORE, Issue 2, 1995 [GR253]\n\n          itu1995(4)\n            ITU Recommendation G.826, 1995 [G.826]\n\n          ansi1997(5)\n            ANSI T1.231, 1997 [T1.231b]\n\n          If a manager changes the value of this\n          object then the SES statistics collected\n          prior to this change must be invalidated.')
sonetSectionCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 1), )
if mibBuilder.loadTexts: sonetSectionCurrentTable.setDescription('The SONET/SDH Section Current table.')
sonetSectionCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: sonetSectionCurrentEntry.setDescription('An entry in the SONET/SDH Section Current table.')
sonetSectionCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,6))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetSectionCurrentStatus.setDescription('This variable indicates the\n          status of the interface.\n          The sonetSectionCurrentStatus\n          is a bit map represented\n          as a sum, therefore,\n          it can represent multiple defects\n          simultaneously.\n          The sonetSectionNoDefect should be\n          set if and only if\n          no other flag is set.\n\n          The various bit positions are:\n                1   sonetSectionNoDefect\n                2   sonetSectionLOS\n                4   sonetSectionLOF')
sonetSectionCurrentESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 1, 1, 2), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetSectionCurrentESs.setDescription('The counter associated with the number of Errored\n          Seconds encountered by a SONET/SDH\n          Section in the current 15 minute interval.')
sonetSectionCurrentSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 1, 1, 3), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetSectionCurrentSESs.setDescription('The counter associated with the number of\n          Severely Errored Seconds\n          encountered by a SONET/SDH Section in the current 15\n          minute interval.')
sonetSectionCurrentSEFSs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 1, 1, 4), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetSectionCurrentSEFSs.setDescription('The counter associated with the number of\n          Severely Errored Framing Seconds\n          encountered by a SONET/SDH Section in the current\n          15 minute interval.')
sonetSectionCurrentCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 1, 1, 5), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetSectionCurrentCVs.setDescription('The counter associated with the number of Coding\n          Violations encountered by a\n          SONET/SDH Section in the current 15 minute interval.')
sonetSectionIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 2), )
if mibBuilder.loadTexts: sonetSectionIntervalTable.setDescription('The SONET/SDH Section Interval table.')
sonetSectionIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "SONET-MIB", "sonetSectionIntervalNumber"))
if mibBuilder.loadTexts: sonetSectionIntervalEntry.setDescription('An entry in the SONET/SDH Section Interval table.')
sonetSectionIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,96)))
if mibBuilder.loadTexts: sonetSectionIntervalNumber.setDescription('A number between 1 and 96, which identifies the\n         interval for which the set of statistics is available.\n         The interval identified by 1 is the most recently\n         completed 15 minute interval,\n         and the interval identified\n         by N is the interval immediately preceding the\n         one identified\n         by N-1.')
sonetSectionIntervalESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 2, 1, 2), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetSectionIntervalESs.setDescription('The counter associated with the number of\n          Errored Seconds encountered\n          by a SONET/SDH Section in a\n          particular 15-minute interval\n          in the past 24 hours.')
sonetSectionIntervalSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 2, 1, 3), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetSectionIntervalSESs.setDescription('The counter associated with the number of\n          Severely Errored Seconds\n          encountered by a SONET/SDH Section in a\n          particular 15-minute interval\n          in the past 24 hours.')
sonetSectionIntervalSEFSs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 2, 1, 4), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetSectionIntervalSEFSs.setDescription('The counter associated with the number of\n          Severely Errored Framing Seconds\n          encountered by a SONET/SDH Section in a\n          particular 15-minute interval\n          in the past 24 hours.')
sonetSectionIntervalCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 2, 1, 5), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetSectionIntervalCVs.setDescription('The counter associated with the number of Coding\n          Violations encountered by a\n          SONET/SDH Section in a particular 15-minute interval\n          in the past 24 hours.')
sonetSectionIntervalValidData = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 2, 2, 1, 6), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetSectionIntervalValidData.setDescription('This variable indicates if the data for this\n           interval is valid.')
sonetLineCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 1), )
if mibBuilder.loadTexts: sonetLineCurrentTable.setDescription('The SONET/SDH Line Current table.')
sonetLineCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: sonetLineCurrentEntry.setDescription('An entry in the SONET/SDH Line Current table.')
sonetLineCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,6))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetLineCurrentStatus.setDescription('This variable indicates the\n          status of the interface.\n          The sonetLineCurrentStatus\n          is a bit map represented\n          as a sum, therefore,\n          it can represent multiple defects\n          simultaneously.\n          The sonetLineNoDefect should be\n          set if and only if\n          no other flag is set.\n\n          The various bit positions are:\n           1   sonetLineNoDefect\n           2   sonetLineAIS\n           4   sonetLineRDI')
sonetLineCurrentESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 1, 1, 2), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetLineCurrentESs.setDescription('The counter associated with the number of Errored\n        Seconds encountered by a SONET/SDH\n        Line in the current 15 minute interval.')
sonetLineCurrentSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 1, 1, 3), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetLineCurrentSESs.setDescription('The counter associated with the number of\n        Severely Errored Seconds\n        encountered by a SONET/SDH Line in the current 15\n        minute\n        interval.')
sonetLineCurrentCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 1, 1, 4), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetLineCurrentCVs.setDescription('The counter associated with the number of Coding\n        Violations encountered by a\n        SONET/SDH Line in the current 15 minute interval.')
sonetLineCurrentUASs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 1, 1, 5), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetLineCurrentUASs.setDescription('The counter associated with the number of\n        Unavailable Seconds\n        encountered by a SONET/SDH Line in the current 15\n        minute\n        interval.')
sonetLineIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 2), )
if mibBuilder.loadTexts: sonetLineIntervalTable.setDescription('The SONET/SDH Line Interval table.')
sonetLineIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "SONET-MIB", "sonetLineIntervalNumber"))
if mibBuilder.loadTexts: sonetLineIntervalEntry.setDescription('An entry in the SONET/SDH Line Interval table.')
sonetLineIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,96)))
if mibBuilder.loadTexts: sonetLineIntervalNumber.setDescription('A number between 1 and 96, which identifies the\n           interval for which the set of statistics is available.\n           The interval identified by 1 is the most recently\n           completed 15 minute interval,\n           and the interval identified\n           by N is the interval immediately preceding the\n           one identified\n           by N-1.')
sonetLineIntervalESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 2, 1, 2), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetLineIntervalESs.setDescription('The counter associated with the number of\n          Errored Seconds encountered\n          by a SONET/SDH Line in a\n          particular 15-minute interval\n          in the past 24 hours.')
sonetLineIntervalSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 2, 1, 3), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetLineIntervalSESs.setDescription('The counter associated with the number of\n          Severely Errored Seconds\n          encountered by a SONET/SDH Line in a\n          particular 15-minute interval\n          in the past 24 hours.')
sonetLineIntervalCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 2, 1, 4), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetLineIntervalCVs.setDescription('The counter associated with the number of Coding\n         Violations encountered by a\n         SONET/SDH Line in a\n         particular 15-minute interval\n         in the past 24 hours.')
sonetLineIntervalUASs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 2, 1, 5), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetLineIntervalUASs.setDescription('The counter associated with the\n         number of Unavailable Seconds\n         encountered by a SONET/SDH Line in\n         a particular 15-minute interval\n         in the past 24 hours.')
sonetLineIntervalValidData = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 3, 2, 1, 6), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetLineIntervalValidData.setDescription('This variable indicates if the data for this\n           interval is valid.')
sonetFarEndLineCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 1), )
if mibBuilder.loadTexts: sonetFarEndLineCurrentTable.setDescription('The SONET/SDH Far End Line Current table.')
sonetFarEndLineCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: sonetFarEndLineCurrentEntry.setDescription('An entry in the SONET/SDH Far End Line Current table.')
sonetFarEndLineCurrentESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 1, 1, 1), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndLineCurrentESs.setDescription('The counter associated with the number of Far\n          End Errored Seconds encountered by a SONET/SDH\n          interface in the current 15 minute interval.')
sonetFarEndLineCurrentSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 1, 1, 2), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndLineCurrentSESs.setDescription('The counter associated with the number of\n          Far End Severely Errored Seconds\n          encountered by a SONET/SDH Medium/Section/Line\n          interface in the current 15 minute\n          interval.')
sonetFarEndLineCurrentCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 1, 1, 3), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndLineCurrentCVs.setDescription('The counter associated with the number of\n          Far End Coding Violations reported via\n          the far end block error count\n          encountered by a\n          SONET/SDH Medium/Section/Line\n          interface in the current 15 minute interval.')
sonetFarEndLineCurrentUASs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 1, 1, 4), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndLineCurrentUASs.setDescription('The counter associated with the number of\n          Far End Unavailable Seconds\n          encountered by a\n          SONET/SDH Medium/Section/Line\n          interface in the current 15 minute interval.')
sonetFarEndLineIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 2), )
if mibBuilder.loadTexts: sonetFarEndLineIntervalTable.setDescription('The SONET/SDH Far End Line Interval table.')
sonetFarEndLineIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "SONET-MIB", "sonetFarEndLineIntervalNumber"))
if mibBuilder.loadTexts: sonetFarEndLineIntervalEntry.setDescription('An entry in the SONET/SDH Far\n        End Line Interval table.')
sonetFarEndLineIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,96)))
if mibBuilder.loadTexts: sonetFarEndLineIntervalNumber.setDescription('A number between 1 and 96, which identifies the\n            interval for which the set of statistics is available.\n            The interval identified by 1 is the most recently\n            completed 15 minute interval,\n            and the interval identified\n            by N is the interval immediately preceding the\n            one identified\n            by N-1.')
sonetFarEndLineIntervalESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 2, 1, 2), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndLineIntervalESs.setDescription('The counter associated with the number of\n           Far End Errored Seconds encountered\n           by a SONET/SDH Line\n           interface in a particular 15-minute interval\n           in the past 24 hours.')
sonetFarEndLineIntervalSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 2, 1, 3), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndLineIntervalSESs.setDescription('The counter associated with the number of\n           Far End Severely Errored Seconds\n           encountered by a SONET/SDH Line\n           interface in a particular 15-minute interval\n           in the past 24 hours.')
sonetFarEndLineIntervalCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 2, 1, 4), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndLineIntervalCVs.setDescription('The counter associated with the number of\n            Far End Coding Violations reported via\n            the far end block error count\n            encountered by a\n            SONET/SDH Line\n            interface in a particular 15-minute interval\n            in the past 24 hours.')
sonetFarEndLineIntervalUASs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 2, 1, 5), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndLineIntervalUASs.setDescription('The counter associated with the number of\n          Far End Unavailable Seconds\n          encountered by a\n          SONET/SDH Line\n          interface in a particular 15-minute interval\n          in the past 24 hours.')
sonetFarEndLineIntervalValidData = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 1, 4, 2, 1, 6), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndLineIntervalValidData.setDescription('This variable indicates if the data for this\n           interval is valid.')
sonetPathCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 1), )
if mibBuilder.loadTexts: sonetPathCurrentTable.setDescription('The SONET/SDH Path Current table.')
sonetPathCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: sonetPathCurrentEntry.setDescription('An entry in the SONET/SDH Path Current table.')
sonetPathCurrentWidth = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7,))).clone(namedValues=NamedValues(("sts1", 1), ("sts3cSTM1", 2), ("sts12cSTM4", 3), ("sts24c", 4), ("sts48cSTM16", 5), ("sts192cSTM64", 6), ("sts768cSTM256", 7),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sonetPathCurrentWidth.setDescription('A value that indicates the type of the SONET/SDH\n        Path.  For SONET, the assigned types are\n        the STS-Nc SPEs, where N = 1, 3, 12, 24, 48, 192 and 768.\n        STS-1 is equal to 51.84 Mbps.  For SDH, the assigned\n        types are the STM-Nc VCs, where N = 1, 4, 16, 64 and 256.')
sonetPathCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,62))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetPathCurrentStatus.setDescription('This variable indicates the\n         status of the interface.\n         The sonetPathCurrentStatus\n         is a bit map represented\n         as a sum, therefore,\n         it can represent multiple defects\n         simultaneously.\n         The sonetPathNoDefect should be\n         set if and only if\n         no other flag is set.\n\n         The various bit positions are:\n            1   sonetPathNoDefect\n            2   sonetPathSTSLOP\n            4   sonetPathSTSAIS\n            8   sonetPathSTSRDI\n           16   sonetPathUnequipped\n           32   sonetPathSignalLabelMismatch')
sonetPathCurrentESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 1, 1, 3), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetPathCurrentESs.setDescription('The counter associated with the number of Errored\n        Seconds encountered by a SONET/SDH\n        Path in the current 15 minute interval.')
sonetPathCurrentSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 1, 1, 4), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetPathCurrentSESs.setDescription('The counter associated with the number of\n        Severely Errored Seconds\n        encountered by a SONET/SDH Path in the current 15\n        minute\n        interval.')
sonetPathCurrentCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 1, 1, 5), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetPathCurrentCVs.setDescription('The counter associated with the number of Coding\n        Violations encountered by a\n        SONET/SDH Path in the current 15 minute interval.')
sonetPathCurrentUASs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 1, 1, 6), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetPathCurrentUASs.setDescription('The counter associated with the number of\n        Unavailable Seconds\n        encountered by a Path in the current\n        15 minute interval.')
sonetPathIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 2), )
if mibBuilder.loadTexts: sonetPathIntervalTable.setDescription('The SONET/SDH Path Interval table.')
sonetPathIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "SONET-MIB", "sonetPathIntervalNumber"))
if mibBuilder.loadTexts: sonetPathIntervalEntry.setDescription('An entry in the SONET/SDH Path Interval table.')
sonetPathIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,96)))
if mibBuilder.loadTexts: sonetPathIntervalNumber.setDescription('A number between 1 and 96, which identifies the\n          interval for which the set of statistics is available.\n          The interval identified by 1 is the most recently\n          completed 15 minute interval,\n          and the interval identified\n          by N is the interval immediately preceding the\n          one identified\n          by N-1.')
sonetPathIntervalESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 2, 1, 2), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetPathIntervalESs.setDescription('The counter associated with the number of\n        Errored Seconds encountered\n        by a SONET/SDH Path in a\n        particular 15-minute interval\n        in the past 24 hours.')
sonetPathIntervalSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 2, 1, 3), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetPathIntervalSESs.setDescription('The counter associated with the number of\n        Severely Errored Seconds\n        encountered by a SONET/SDH Path in\n        a particular 15-minute interval\n        in the past 24 hours.')
sonetPathIntervalCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 2, 1, 4), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetPathIntervalCVs.setDescription('The counter associated with the number of Coding\n        Violations encountered by a\n        SONET/SDH Path in a particular 15-minute interval\n        in the past 24 hours.')
sonetPathIntervalUASs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 2, 1, 5), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetPathIntervalUASs.setDescription('The counter associated with the number of\n        Unavailable Seconds\n        encountered by a Path in a\n        particular 15-minute interval\n        in the past 24 hours.')
sonetPathIntervalValidData = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 1, 2, 1, 6), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetPathIntervalValidData.setDescription('This variable indicates if the data for this\n           interval is valid.')
sonetFarEndPathCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 1), )
if mibBuilder.loadTexts: sonetFarEndPathCurrentTable.setDescription('The SONET/SDH Far End Path Current table.')
sonetFarEndPathCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: sonetFarEndPathCurrentEntry.setDescription('An entry in the SONET/SDH Far End Path Current table.')
sonetFarEndPathCurrentESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 1, 1, 1), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndPathCurrentESs.setDescription('The counter associated with the number of Far\n            End Errored Seconds encountered by a SONET/SDH\n            interface in the current 15 minute interval.')
sonetFarEndPathCurrentSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 1, 1, 2), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndPathCurrentSESs.setDescription('The counter associated with the number of\n            Far End Severely Errored Seconds\n            encountered by a SONET/SDH Path\n            interface in the current 15 minute\n            interval.')
sonetFarEndPathCurrentCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 1, 1, 3), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndPathCurrentCVs.setDescription('The counter associated with the number of\n            Far End Coding Violations reported via\n            the far end block error count\n            encountered by a\n            SONET/SDH Path interface in\n            the current 15 minute interval.')
sonetFarEndPathCurrentUASs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 1, 1, 4), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndPathCurrentUASs.setDescription('The counter associated with the number of\n          Far End Unavailable Seconds\n          encountered by a\n          SONET/SDH Path interface in\n          the current 15 minute interval.')
sonetFarEndPathIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 2), )
if mibBuilder.loadTexts: sonetFarEndPathIntervalTable.setDescription('The SONET/SDH Far End Path Interval table.')
sonetFarEndPathIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "SONET-MIB", "sonetFarEndPathIntervalNumber"))
if mibBuilder.loadTexts: sonetFarEndPathIntervalEntry.setDescription('An entry in the SONET/SDH Far\n          End Path Interval table.')
sonetFarEndPathIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,96)))
if mibBuilder.loadTexts: sonetFarEndPathIntervalNumber.setDescription('A number between 1 and 96, which identifies the\n           interval for which the set of statistics is available.\n           The interval identified by 1 is the most recently\n           completed 15 minute interval,\n           and the interval identified\n           by N is the interval immediately preceding the\n           one identified\n           by N-1.')
sonetFarEndPathIntervalESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 2, 1, 2), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndPathIntervalESs.setDescription('The counter associated with the number of\n           Far End Errored Seconds encountered\n           by a SONET/SDH Path interface in a\n           particular 15-minute interval\n           in the past 24 hours.')
sonetFarEndPathIntervalSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 2, 1, 3), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndPathIntervalSESs.setDescription('The counter associated with the number of\n           Far End Severely Errored Seconds\n           encountered by a SONET/SDH Path interface\n           in a particular 15-minute interval\n           in the past 24 hours.')
sonetFarEndPathIntervalCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 2, 1, 4), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndPathIntervalCVs.setDescription('The counter associated with the number of\n            Far End Coding Violations reported via\n            the far end block error count\n            encountered by a\n            SONET/SDH Path interface\n            in a particular 15-minute interval\n            in the past 24 hours.')
sonetFarEndPathIntervalUASs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 2, 1, 5), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndPathIntervalUASs.setDescription('The counter associated with the number of\n          Far End Unavailable Seconds\n          encountered by a\n          SONET/SDH Path interface in\n          a particular 15-minute interval\n          in the past 24 hours.')
sonetFarEndPathIntervalValidData = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 2, 2, 2, 1, 6), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndPathIntervalValidData.setDescription('This variable indicates if the data for this\n           interval is valid.')
sonetVTCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 1), )
if mibBuilder.loadTexts: sonetVTCurrentTable.setDescription('The SONET/SDH VT Current table.')
sonetVTCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: sonetVTCurrentEntry.setDescription('An entry in the SONET/SDH VT Current table.')
sonetVTCurrentWidth = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("vtWidth15VC11", 1), ("vtWidth2VC12", 2), ("vtWidth3", 3), ("vtWidth6VC2", 4), ("vtWidth6c", 5),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sonetVTCurrentWidth.setDescription('A value that indicates the type of the SONET\n        VT and SDH VC.  Assigned widths are\n        VT1.5/VC11, VT2/VC12, VT3, VT6/VC2, and VT6c.')
sonetVTCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,126))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetVTCurrentStatus.setDescription('This variable indicates the\n         status of the interface.\n         The sonetVTCurrentStatus\n         is a bit map represented\n         as a sum, therefore,\n         it can represent multiple defects\n         and failures\n         simultaneously.\n         The sonetVTNoDefect should be\n         set if and only if\n         no other flag is set.\n\n         The various bit positions are:\n            1   sonetVTNoDefect\n            2   sonetVTLOP\n            4   sonetVTPathAIS\n            8   sonetVTPathRDI\n           16   sonetVTPathRFI\n           32   sonetVTUnequipped\n           64   sonetVTSignalLabelMismatch')
sonetVTCurrentESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 1, 1, 3), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetVTCurrentESs.setDescription('The counter associated with the number of Errored\n        Seconds encountered by a SONET/SDH\n        VT in the current 15 minute interval.')
sonetVTCurrentSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 1, 1, 4), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetVTCurrentSESs.setDescription('The counter associated with the number of\n        Severely Errored Seconds\n        encountered by a SONET/SDH VT in the current 15 minute\n        interval.')
sonetVTCurrentCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 1, 1, 5), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetVTCurrentCVs.setDescription('The counter associated with the number of Coding\n        Violations encountered by a\n        SONET/SDH VT in the current 15 minute interval.')
sonetVTCurrentUASs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 1, 1, 6), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetVTCurrentUASs.setDescription('The counter associated with the number of\n        Unavailable Seconds\n        encountered by a VT in the current\n        15 minute interval.')
sonetVTIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 2), )
if mibBuilder.loadTexts: sonetVTIntervalTable.setDescription('The SONET/SDH VT Interval table.')
sonetVTIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "SONET-MIB", "sonetVTIntervalNumber"))
if mibBuilder.loadTexts: sonetVTIntervalEntry.setDescription('An entry in the SONET/SDH VT Interval table.')
sonetVTIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,96)))
if mibBuilder.loadTexts: sonetVTIntervalNumber.setDescription('A number between 1 and 96, which identifies the\n         interval for which the set of statistics is available.\n         The interval identified by 1 is the most recently\n         completed 15 minute interval,\n         and the interval identified\n         by N is the interval immediately preceding the\n         one identified\n         by N-1.')
sonetVTIntervalESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 2, 1, 2), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetVTIntervalESs.setDescription('The counter associated with the number of\n        Errored Seconds encountered\n        by a SONET/SDH VT in a particular 15-minute interval\n        in the past 24 hours.')
sonetVTIntervalSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 2, 1, 3), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetVTIntervalSESs.setDescription('The counter associated with the number of\n        Severely Errored Seconds\n        encountered by a SONET/SDH VT\n        in a particular 15-minute interval\n        in the past 24 hours.')
sonetVTIntervalCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 2, 1, 4), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetVTIntervalCVs.setDescription('The counter associated with the number of Coding\n        Violations encountered by a\n        SONET/SDH VT in a particular 15-minute interval\n        in the past 24 hours.')
sonetVTIntervalUASs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 2, 1, 5), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetVTIntervalUASs.setDescription('The counter associated with the number of\n        Unavailable Seconds\n        encountered by a VT in a particular 15-minute interval\n        in the past 24 hours.')
sonetVTIntervalValidData = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 1, 2, 1, 6), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetVTIntervalValidData.setDescription('This variable indicates if the data for this\n           interval is valid.')
sonetFarEndVTCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 1), )
if mibBuilder.loadTexts: sonetFarEndVTCurrentTable.setDescription('The SONET/SDH Far End VT Current table.')
sonetFarEndVTCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: sonetFarEndVTCurrentEntry.setDescription('An entry in the SONET/SDH Far End VT Current table.')
sonetFarEndVTCurrentESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 1, 1, 1), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndVTCurrentESs.setDescription('The counter associated with the number of Far\n           End Errored Seconds encountered by a SONET/SDH\n           interface in the current 15 minute interval.')
sonetFarEndVTCurrentSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 1, 1, 2), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndVTCurrentSESs.setDescription('The counter associated with the number of\n           Far End Severely Errored Seconds\n           encountered by a SONET/SDH VT interface\n           in the current 15 minute\n           interval.')
sonetFarEndVTCurrentCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 1, 1, 3), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndVTCurrentCVs.setDescription('The counter associated with the number of\n           Far End Coding Violations reported via\n           the far end block error count\n           encountered by a\n           SONET/SDH VT interface\n           in the current 15 minute interval.')
sonetFarEndVTCurrentUASs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 1, 1, 4), PerfCurrentCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndVTCurrentUASs.setDescription('The counter associated with the number of\n         Far End Unavailable Seconds\n         encountered by a\n         SONET/SDH VT interface\n         in the current 15 minute interval.')
sonetFarEndVTIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 2), )
if mibBuilder.loadTexts: sonetFarEndVTIntervalTable.setDescription('The SONET/SDH Far End VT Interval table.')
sonetFarEndVTIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "SONET-MIB", "sonetFarEndVTIntervalNumber"))
if mibBuilder.loadTexts: sonetFarEndVTIntervalEntry.setDescription('An entry in the SONET/SDH Far\n         End VT Interval table.')
sonetFarEndVTIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,96)))
if mibBuilder.loadTexts: sonetFarEndVTIntervalNumber.setDescription('A number between 1 and 96, which identifies the\n          interval for which the set of statistics is available.\n          The interval identified by 1 is the most recently\n          completed 15 minute interval,\n          and the interval identified\n          by N is the interval immediately preceding the\n          one identified\n          by N-1.')
sonetFarEndVTIntervalESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 2, 1, 2), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndVTIntervalESs.setDescription('The counter associated with the number of\n             Far End Errored Seconds encountered\n             by a SONET/SDH VT interface\n             in a particular 15-minute interval\n             in the past 24 hours.')
sonetFarEndVTIntervalSESs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 2, 1, 3), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndVTIntervalSESs.setDescription('The counter associated with the number of\n             Far End Severely Errored Seconds\n             encountered by a SONET/SDH VT interface\n             in a particular 15-minute interval\n             in the past 24 hours.')
sonetFarEndVTIntervalCVs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 2, 1, 4), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndVTIntervalCVs.setDescription('The counter associated with the number of\n            Far End Coding Violations reported via\n            the far end block error count\n            encountered by a\n            SONET/SDH VT interface in a\n            particular 15-minute interval\n            in the past 24 hours.')
sonetFarEndVTIntervalUASs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 2, 1, 5), PerfIntervalCount()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndVTIntervalUASs.setDescription('The counter associated with the number of\n          Far End Unavailable Seconds\n          encountered by a\n          SONET/SDH VT interface in a\n          particular 15-minute interval\n          in the past 24 hours.')
sonetFarEndVTIntervalValidData = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 39, 3, 2, 2, 1, 6), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sonetFarEndVTIntervalValidData.setDescription('This variable indicates if the data for this\n           interval is valid.')
sonetConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 4))
sonetGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 4, 1))
sonetCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 39, 4, 2))
sonetCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 39, 4, 2, 1)).setObjects(*(("SONET-MIB", "sonetMediumStuff"), ("SONET-MIB", "sonetSectionStuff"), ("SONET-MIB", "sonetLineStuff"), ("SONET-MIB", "sonetFarEndLineStuff"), ("SONET-MIB", "sonetPathStuff"), ("SONET-MIB", "sonetFarEndPathStuff"), ("SONET-MIB", "sonetVTStuff"), ("SONET-MIB", "sonetFarEndVTStuff"),))
if mibBuilder.loadTexts: sonetCompliance.setDescription('The compliance statement for SONET/SDH interfaces.')
sonetCompliance2 = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 39, 4, 2, 2)).setObjects(*(("SONET-MIB", "sonetMediumStuff2"), ("SONET-MIB", "sonetSectionStuff2"),))
if mibBuilder.loadTexts: sonetCompliance2.setDescription('The compliance statement for SONET/SDH interfaces.')
sonetMediumStuff = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 1)).setObjects(*(("SONET-MIB", "sonetMediumType"), ("SONET-MIB", "sonetMediumTimeElapsed"), ("SONET-MIB", "sonetMediumValidIntervals"), ("SONET-MIB", "sonetMediumLineCoding"), ("SONET-MIB", "sonetMediumLineType"), ("SONET-MIB", "sonetMediumCircuitIdentifier"),))
if mibBuilder.loadTexts: sonetMediumStuff.setDescription('A collection of objects providing configuration\n               information applicable to all SONET/SDH interfaces.')
sonetSectionStuff = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 2)).setObjects(*(("SONET-MIB", "sonetSectionCurrentStatus"), ("SONET-MIB", "sonetSectionCurrentESs"), ("SONET-MIB", "sonetSectionCurrentSESs"), ("SONET-MIB", "sonetSectionCurrentSEFSs"), ("SONET-MIB", "sonetSectionCurrentCVs"), ("SONET-MIB", "sonetSectionIntervalESs"), ("SONET-MIB", "sonetSectionIntervalSESs"), ("SONET-MIB", "sonetSectionIntervalSEFSs"), ("SONET-MIB", "sonetSectionIntervalCVs"),))
if mibBuilder.loadTexts: sonetSectionStuff.setDescription('A collection of objects providing information\n               specific to SONET/SDH Section interfaces.')
sonetLineStuff = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 3)).setObjects(*(("SONET-MIB", "sonetLineCurrentStatus"), ("SONET-MIB", "sonetLineCurrentESs"), ("SONET-MIB", "sonetLineCurrentSESs"), ("SONET-MIB", "sonetLineCurrentCVs"), ("SONET-MIB", "sonetLineCurrentUASs"), ("SONET-MIB", "sonetLineIntervalESs"), ("SONET-MIB", "sonetLineIntervalSESs"), ("SONET-MIB", "sonetLineIntervalCVs"), ("SONET-MIB", "sonetLineIntervalUASs"),))
if mibBuilder.loadTexts: sonetLineStuff.setDescription('A collection of objects providing information\n               specific to SONET/SDH Line interfaces.')
sonetFarEndLineStuff = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 4)).setObjects(*(("SONET-MIB", "sonetFarEndLineCurrentESs"), ("SONET-MIB", "sonetFarEndLineCurrentSESs"), ("SONET-MIB", "sonetFarEndLineCurrentCVs"), ("SONET-MIB", "sonetFarEndLineCurrentUASs"), ("SONET-MIB", "sonetFarEndLineIntervalESs"), ("SONET-MIB", "sonetFarEndLineIntervalSESs"), ("SONET-MIB", "sonetFarEndLineIntervalCVs"), ("SONET-MIB", "sonetFarEndLineIntervalUASs"),))
if mibBuilder.loadTexts: sonetFarEndLineStuff.setDescription('A collection of objects providing information\n               specific to SONET/SDH Line interfaces,\n               and maintaining Line Far End information.')
sonetPathStuff = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 5)).setObjects(*(("SONET-MIB", "sonetPathCurrentWidth"), ("SONET-MIB", "sonetPathCurrentStatus"), ("SONET-MIB", "sonetPathCurrentESs"), ("SONET-MIB", "sonetPathCurrentSESs"), ("SONET-MIB", "sonetPathCurrentCVs"), ("SONET-MIB", "sonetPathCurrentUASs"), ("SONET-MIB", "sonetPathIntervalESs"), ("SONET-MIB", "sonetPathIntervalSESs"), ("SONET-MIB", "sonetPathIntervalCVs"), ("SONET-MIB", "sonetPathIntervalUASs"),))
if mibBuilder.loadTexts: sonetPathStuff.setDescription('A collection of objects providing information\n               specific to SONET/SDH Path interfaces.')
sonetFarEndPathStuff = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 6)).setObjects(*(("SONET-MIB", "sonetFarEndPathCurrentESs"), ("SONET-MIB", "sonetFarEndPathCurrentSESs"), ("SONET-MIB", "sonetFarEndPathCurrentCVs"), ("SONET-MIB", "sonetFarEndPathCurrentUASs"), ("SONET-MIB", "sonetFarEndPathIntervalESs"), ("SONET-MIB", "sonetFarEndPathIntervalSESs"), ("SONET-MIB", "sonetFarEndPathIntervalCVs"), ("SONET-MIB", "sonetFarEndPathIntervalUASs"),))
if mibBuilder.loadTexts: sonetFarEndPathStuff.setDescription('A collection of objects providing information\n               specific to SONET/SDH Path interfaces,\n               and maintaining Path Far End information.')
sonetVTStuff = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 7)).setObjects(*(("SONET-MIB", "sonetVTCurrentWidth"), ("SONET-MIB", "sonetVTCurrentStatus"), ("SONET-MIB", "sonetVTCurrentESs"), ("SONET-MIB", "sonetVTCurrentSESs"), ("SONET-MIB", "sonetVTCurrentCVs"), ("SONET-MIB", "sonetVTCurrentUASs"), ("SONET-MIB", "sonetVTIntervalESs"), ("SONET-MIB", "sonetVTIntervalSESs"), ("SONET-MIB", "sonetVTIntervalCVs"), ("SONET-MIB", "sonetVTIntervalUASs"),))
if mibBuilder.loadTexts: sonetVTStuff.setDescription('A collection of objects providing information\n               specific to SONET/SDH VT interfaces.')
sonetFarEndVTStuff = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 8)).setObjects(*(("SONET-MIB", "sonetFarEndVTCurrentESs"), ("SONET-MIB", "sonetFarEndVTCurrentSESs"), ("SONET-MIB", "sonetFarEndVTCurrentCVs"), ("SONET-MIB", "sonetFarEndVTCurrentUASs"), ("SONET-MIB", "sonetFarEndVTIntervalESs"), ("SONET-MIB", "sonetFarEndVTIntervalSESs"), ("SONET-MIB", "sonetFarEndVTIntervalCVs"), ("SONET-MIB", "sonetFarEndVTIntervalUASs"),))
if mibBuilder.loadTexts: sonetFarEndVTStuff.setDescription('A collection of objects providing information\n               specific to SONET/SDH VT interfaces,\n               and maintaining VT Far End information.')
sonetMediumStuff2 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 9)).setObjects(*(("SONET-MIB", "sonetMediumType"), ("SONET-MIB", "sonetMediumTimeElapsed"), ("SONET-MIB", "sonetMediumValidIntervals"), ("SONET-MIB", "sonetMediumLineCoding"), ("SONET-MIB", "sonetMediumLineType"), ("SONET-MIB", "sonetMediumCircuitIdentifier"), ("SONET-MIB", "sonetMediumInvalidIntervals"), ("SONET-MIB", "sonetMediumLoopbackConfig"), ("SONET-MIB", "sonetSESthresholdSet"),))
if mibBuilder.loadTexts: sonetMediumStuff2.setDescription('A collection of objects providing configuration\n               information applicable to all SONET/SDH interfaces.')
sonetSectionStuff2 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 10)).setObjects(*(("SONET-MIB", "sonetSectionCurrentStatus"), ("SONET-MIB", "sonetSectionCurrentESs"), ("SONET-MIB", "sonetSectionCurrentSESs"), ("SONET-MIB", "sonetSectionCurrentSEFSs"), ("SONET-MIB", "sonetSectionCurrentCVs"), ("SONET-MIB", "sonetSectionIntervalESs"), ("SONET-MIB", "sonetSectionIntervalSESs"), ("SONET-MIB", "sonetSectionIntervalSEFSs"), ("SONET-MIB", "sonetSectionIntervalCVs"), ("SONET-MIB", "sonetSectionIntervalValidData"),))
if mibBuilder.loadTexts: sonetSectionStuff2.setDescription('A collection of objects providing information\n               specific to SONET/SDH Section interfaces.')
sonetLineStuff2 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 11)).setObjects(*(("SONET-MIB", "sonetLineCurrentStatus"), ("SONET-MIB", "sonetLineCurrentESs"), ("SONET-MIB", "sonetLineCurrentSESs"), ("SONET-MIB", "sonetLineCurrentCVs"), ("SONET-MIB", "sonetLineCurrentUASs"), ("SONET-MIB", "sonetLineIntervalESs"), ("SONET-MIB", "sonetLineIntervalSESs"), ("SONET-MIB", "sonetLineIntervalCVs"), ("SONET-MIB", "sonetLineIntervalUASs"), ("SONET-MIB", "sonetLineIntervalValidData"),))
if mibBuilder.loadTexts: sonetLineStuff2.setDescription('A collection of objects providing information\n               specific to SONET/SDH Line interfaces.')
sonetPathStuff2 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 12)).setObjects(*(("SONET-MIB", "sonetPathCurrentWidth"), ("SONET-MIB", "sonetPathCurrentStatus"), ("SONET-MIB", "sonetPathCurrentESs"), ("SONET-MIB", "sonetPathCurrentSESs"), ("SONET-MIB", "sonetPathCurrentCVs"), ("SONET-MIB", "sonetPathCurrentUASs"), ("SONET-MIB", "sonetPathIntervalESs"), ("SONET-MIB", "sonetPathIntervalSESs"), ("SONET-MIB", "sonetPathIntervalCVs"), ("SONET-MIB", "sonetPathIntervalUASs"), ("SONET-MIB", "sonetPathIntervalValidData"),))
if mibBuilder.loadTexts: sonetPathStuff2.setDescription('A collection of objects providing information\n               specific to SONET/SDH Path interfaces.')
sonetVTStuff2 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 13)).setObjects(*(("SONET-MIB", "sonetVTCurrentWidth"), ("SONET-MIB", "sonetVTCurrentStatus"), ("SONET-MIB", "sonetVTCurrentESs"), ("SONET-MIB", "sonetVTCurrentSESs"), ("SONET-MIB", "sonetVTCurrentCVs"), ("SONET-MIB", "sonetVTCurrentUASs"), ("SONET-MIB", "sonetVTIntervalESs"), ("SONET-MIB", "sonetVTIntervalSESs"), ("SONET-MIB", "sonetVTIntervalCVs"), ("SONET-MIB", "sonetVTIntervalUASs"), ("SONET-MIB", "sonetVTIntervalValidData"),))
if mibBuilder.loadTexts: sonetVTStuff2.setDescription('A collection of objects providing information\n               specific to SONET/SDH VT interfaces.')
sonetFarEndLineStuff2 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 14)).setObjects(*(("SONET-MIB", "sonetFarEndLineCurrentESs"), ("SONET-MIB", "sonetFarEndLineCurrentSESs"), ("SONET-MIB", "sonetFarEndLineCurrentCVs"), ("SONET-MIB", "sonetFarEndLineCurrentUASs"), ("SONET-MIB", "sonetFarEndLineIntervalESs"), ("SONET-MIB", "sonetFarEndLineIntervalSESs"), ("SONET-MIB", "sonetFarEndLineIntervalCVs"), ("SONET-MIB", "sonetFarEndLineIntervalUASs"), ("SONET-MIB", "sonetFarEndLineIntervalValidData"),))
if mibBuilder.loadTexts: sonetFarEndLineStuff2.setDescription('A collection of objects providing information\n               specific to SONET/SDH Line interfaces,\n               and maintaining Line Far End information.')
sonetFarEndPathStuff2 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 15)).setObjects(*(("SONET-MIB", "sonetFarEndPathCurrentESs"), ("SONET-MIB", "sonetFarEndPathCurrentSESs"), ("SONET-MIB", "sonetFarEndPathCurrentCVs"), ("SONET-MIB", "sonetFarEndPathCurrentUASs"), ("SONET-MIB", "sonetFarEndPathIntervalESs"), ("SONET-MIB", "sonetFarEndPathIntervalSESs"), ("SONET-MIB", "sonetFarEndPathIntervalCVs"), ("SONET-MIB", "sonetFarEndPathIntervalUASs"), ("SONET-MIB", "sonetFarEndPathIntervalValidData"),))
if mibBuilder.loadTexts: sonetFarEndPathStuff2.setDescription('A collection of objects providing information\n               specific to SONET/SDH Path interfaces,\n               and maintaining Path Far End information.')
sonetFarEndVTStuff2 = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 39, 4, 1, 16)).setObjects(*(("SONET-MIB", "sonetFarEndVTCurrentESs"), ("SONET-MIB", "sonetFarEndVTCurrentSESs"), ("SONET-MIB", "sonetFarEndVTCurrentCVs"), ("SONET-MIB", "sonetFarEndVTCurrentUASs"), ("SONET-MIB", "sonetFarEndVTIntervalESs"), ("SONET-MIB", "sonetFarEndVTIntervalSESs"), ("SONET-MIB", "sonetFarEndVTIntervalCVs"), ("SONET-MIB", "sonetFarEndVTIntervalUASs"), ("SONET-MIB", "sonetFarEndVTIntervalValidData"),))
if mibBuilder.loadTexts: sonetFarEndVTStuff2.setDescription('A collection of objects providing information\n               specific to SONET/SDH VT interfaces,\n               and maintaining VT Far End information.')
mibBuilder.exportSymbols("SONET-MIB", sonetObjects=sonetObjects, sonetSectionIntervalCVs=sonetSectionIntervalCVs, sonetPathIntervalEntry=sonetPathIntervalEntry, sonetLineIntervalSESs=sonetLineIntervalSESs, sonetLineIntervalUASs=sonetLineIntervalUASs, sonetPathCurrentEntry=sonetPathCurrentEntry, sonetSectionStuff=sonetSectionStuff, sonetLineCurrentUASs=sonetLineCurrentUASs, sonetFarEndLineIntervalUASs=sonetFarEndLineIntervalUASs, sonetPathIntervalTable=sonetPathIntervalTable, sonetLineStuff=sonetLineStuff, sonetPathCurrentSESs=sonetPathCurrentSESs, sonetConformance=sonetConformance, sonetFarEndVTIntervalESs=sonetFarEndVTIntervalESs, sonetLineIntervalCVs=sonetLineIntervalCVs, sonetFarEndPathIntervalUASs=sonetFarEndPathIntervalUASs, sonetPathIntervalSESs=sonetPathIntervalSESs, sonetFarEndPathStuff2=sonetFarEndPathStuff2, sonetFarEndPathCurrentSESs=sonetFarEndPathCurrentSESs, sonetMediumEntry=sonetMediumEntry, sonetFarEndPathIntervalCVs=sonetFarEndPathIntervalCVs, sonetFarEndLineIntervalCVs=sonetFarEndLineIntervalCVs, sonetCompliance=sonetCompliance, sonetLine=sonetLine, sonetVTCurrentWidth=sonetVTCurrentWidth, sonetLineCurrentTable=sonetLineCurrentTable, sonetLineCurrentCVs=sonetLineCurrentCVs, sonetFarEndLineCurrentESs=sonetFarEndLineCurrentESs, sonetSectionIntervalSESs=sonetSectionIntervalSESs, sonetPath=sonetPath, sonetVTIntervalEntry=sonetVTIntervalEntry, sonetPathIntervalUASs=sonetPathIntervalUASs, sonetFarEndVTIntervalTable=sonetFarEndVTIntervalTable, sonetFarEndLineIntervalTable=sonetFarEndLineIntervalTable, sonetObjectsPath=sonetObjectsPath, sonetMediumValidIntervals=sonetMediumValidIntervals, sonetSectionCurrentESs=sonetSectionCurrentESs, sonetVTIntervalSESs=sonetVTIntervalSESs, sonetMediumStuff=sonetMediumStuff, sonetFarEndPathIntervalSESs=sonetFarEndPathIntervalSESs, sonetMediumStuff2=sonetMediumStuff2, sonetPathCurrentUASs=sonetPathCurrentUASs, sonetPathStuff=sonetPathStuff, sonetLineIntervalNumber=sonetLineIntervalNumber, sonetMIB=sonetMIB, sonetFarEndPathCurrentCVs=sonetFarEndPathCurrentCVs, sonetFarEndVTCurrentSESs=sonetFarEndVTCurrentSESs, sonetPathCurrentCVs=sonetPathCurrentCVs, sonetLineIntervalValidData=sonetLineIntervalValidData, sonetPathIntervalCVs=sonetPathIntervalCVs, sonetFarEndPathIntervalTable=sonetFarEndPathIntervalTable, sonetSectionCurrentCVs=sonetSectionCurrentCVs, sonetMedium=sonetMedium, sonetFarEndLineIntervalESs=sonetFarEndLineIntervalESs, sonetFarEndVTStuff=sonetFarEndVTStuff, sonetMediumLineType=sonetMediumLineType, sonetGroups=sonetGroups, sonetLineCurrentEntry=sonetLineCurrentEntry, sonetFarEndVTIntervalSESs=sonetFarEndVTIntervalSESs, sonetSectionCurrentSEFSs=sonetSectionCurrentSEFSs, sonetFarEndLineCurrentTable=sonetFarEndLineCurrentTable, sonetFarEndLineIntervalValidData=sonetFarEndLineIntervalValidData, sonetMediumLineCoding=sonetMediumLineCoding, sonetFarEndLineCurrentUASs=sonetFarEndLineCurrentUASs, sonetCompliances=sonetCompliances, sonetPathIntervalValidData=sonetPathIntervalValidData, sonetFarEndPathCurrentESs=sonetFarEndPathCurrentESs, sonetVTIntervalUASs=sonetVTIntervalUASs, sonetVTCurrentTable=sonetVTCurrentTable, sonetSectionStuff2=sonetSectionStuff2, sonetMediumCircuitIdentifier=sonetMediumCircuitIdentifier, sonetPathIntervalESs=sonetPathIntervalESs, sonetMediumLoopbackConfig=sonetMediumLoopbackConfig, sonetPathCurrentESs=sonetPathCurrentESs, sonetVTIntervalCVs=sonetVTIntervalCVs, sonetSectionIntervalESs=sonetSectionIntervalESs, sonetPathCurrentWidth=sonetPathCurrentWidth, sonetFarEndLine=sonetFarEndLine, sonetSectionIntervalTable=sonetSectionIntervalTable, sonetFarEndVTCurrentTable=sonetFarEndVTCurrentTable, sonetFarEndPathStuff=sonetFarEndPathStuff, sonetLineStuff2=sonetLineStuff2, sonetVTIntervalNumber=sonetVTIntervalNumber, sonetFarEndVTCurrentESs=sonetFarEndVTCurrentESs, sonetFarEndPathCurrentEntry=sonetFarEndPathCurrentEntry, sonetPathStuff2=sonetPathStuff2, sonetSection=sonetSection, sonetFarEndLineStuff2=sonetFarEndLineStuff2, sonetMediumTimeElapsed=sonetMediumTimeElapsed, sonetFarEndVTIntervalEntry=sonetFarEndVTIntervalEntry, sonetMediumTable=sonetMediumTable, sonetFarEndVT=sonetFarEndVT, sonetSectionIntervalValidData=sonetSectionIntervalValidData, sonetVTStuff=sonetVTStuff, sonetLineIntervalEntry=sonetLineIntervalEntry, sonetPathIntervalNumber=sonetPathIntervalNumber, sonetSectionIntervalNumber=sonetSectionIntervalNumber, sonetVTCurrentCVs=sonetVTCurrentCVs, sonetFarEndVTCurrentEntry=sonetFarEndVTCurrentEntry, PYSNMP_MODULE_ID=sonetMIB, sonetFarEndLineCurrentSESs=sonetFarEndLineCurrentSESs, sonetFarEndVTCurrentUASs=sonetFarEndVTCurrentUASs, sonetLineCurrentSESs=sonetLineCurrentSESs, sonetFarEndLineCurrentEntry=sonetFarEndLineCurrentEntry, sonetVTIntervalValidData=sonetVTIntervalValidData, sonetFarEndVTStuff2=sonetFarEndVTStuff2, sonetFarEndVTCurrentCVs=sonetFarEndVTCurrentCVs, sonetFarEndVTIntervalCVs=sonetFarEndVTIntervalCVs, sonetSectionCurrentEntry=sonetSectionCurrentEntry, sonetSectionIntervalSEFSs=sonetSectionIntervalSEFSs, sonetPathCurrentStatus=sonetPathCurrentStatus, sonetLineCurrentStatus=sonetLineCurrentStatus, sonetFarEndLineIntervalSESs=sonetFarEndLineIntervalSESs, sonetFarEndPathCurrentUASs=sonetFarEndPathCurrentUASs, sonetLineIntervalTable=sonetLineIntervalTable, sonetFarEndPathIntervalEntry=sonetFarEndPathIntervalEntry, sonetMediumInvalidIntervals=sonetMediumInvalidIntervals, sonetVT=sonetVT, sonetFarEndPathIntervalESs=sonetFarEndPathIntervalESs, sonetFarEndVTIntervalNumber=sonetFarEndVTIntervalNumber, sonetFarEndPathCurrentTable=sonetFarEndPathCurrentTable, sonetSectionCurrentStatus=sonetSectionCurrentStatus, sonetLineCurrentESs=sonetLineCurrentESs, sonetFarEndLineIntervalNumber=sonetFarEndLineIntervalNumber, sonetVTCurrentStatus=sonetVTCurrentStatus, sonetVTCurrentESs=sonetVTCurrentESs, sonetFarEndVTIntervalValidData=sonetFarEndVTIntervalValidData, sonetSESthresholdSet=sonetSESthresholdSet, sonetVTIntervalTable=sonetVTIntervalTable, sonetSectionIntervalEntry=sonetSectionIntervalEntry, sonetFarEndLineCurrentCVs=sonetFarEndLineCurrentCVs, sonetVTIntervalESs=sonetVTIntervalESs, sonetVTStuff2=sonetVTStuff2, sonetFarEndPathIntervalNumber=sonetFarEndPathIntervalNumber, sonetVTCurrentEntry=sonetVTCurrentEntry, sonetObjectsVT=sonetObjectsVT, sonetCompliance2=sonetCompliance2, sonetFarEndPath=sonetFarEndPath, sonetSectionCurrentSESs=sonetSectionCurrentSESs, sonetVTCurrentUASs=sonetVTCurrentUASs, sonetFarEndLineIntervalEntry=sonetFarEndLineIntervalEntry, sonetVTCurrentSESs=sonetVTCurrentSESs, sonetMediumType=sonetMediumType, sonetSectionCurrentTable=sonetSectionCurrentTable, sonetPathCurrentTable=sonetPathCurrentTable, sonetLineIntervalESs=sonetLineIntervalESs, sonetFarEndVTIntervalUASs=sonetFarEndVTIntervalUASs, sonetFarEndPathIntervalValidData=sonetFarEndPathIntervalValidData, sonetFarEndLineStuff=sonetFarEndLineStuff)
